import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMAccelerometer(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreMotion.CMAuthorizationStatus)

    def test_constants(self):
        self.assertEqual(CoreMotion.CMAuthorizationStatusNotDetermined, 0)
        self.assertEqual(CoreMotion.CMAuthorizationStatusRestricted, 1)
        self.assertEqual(CoreMotion.CMAuthorizationStatusDenied, 2)
        self.assertEqual(CoreMotion.CMAuthorizationStatusAuthorized, 3)



import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMFallDetectionEvent(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreMotion.CMFallDetectionEventUserResolution)

    def test_constants(self):
        self.assertEqual(CoreMotion.CMFallDetectionEventUserResolutionConfirmed, 0)
        self.assertEqual(CoreMotion.CMFallDetectionEventUserResolutionDismissed, 1)
        self.assertEqual(CoreMotion.CMFallDetectionEventUserResolutionRejected, 2)
        self.assertEqual(CoreMotion.CMFallDetectionEventUserResolutionUnresponsive, 3)



import CoreMotion
from PyObjCTools.TestSupport import TestCase


class TestCMDeviceMotion(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreMotion.CMDeviceMotionSensorLocation)
        self.assertIsEnumType(CoreMotion.CMMagneticFieldCalibrationAccuracy)

    def test_constants(self):
        self.assertEqual(CoreMotion.CMMagneticFieldCalibrationAccuracyUncalibrated, -1)
        self.assertEqual(CoreMotion.CMMagneticFieldCalibrationAccuracyLow, 0)
        self.assertEqual(CoreMotion.CMMagneticFieldCalibrationAccuracyMedium, 1)
        self.assertEqual(CoreMotion.CMMagneticFieldCalibrationAccuracyHigh, 2)

        self.assertEqual(CoreMotion.CMDeviceMotionSensorLocationDefault, 0)
        self.assertEqual(CoreMotion.CMDeviceMotionSensorLocationHeadphoneLeft, 1)
        self.assertEqual(CoreMotion.CMDeviceMotionSensorLocationHeadphoneRight, 2)

    def test_structs(self):
        v = CoreMotion.CMCalibratedMagneticField()
        self.assertEqual(v.field, CoreMotion.CMMagneticField())
        self.assertEqual(v.accuracy, 0)
        self.assertPickleRoundTrips(v)
